@@ -8,9 +8,15 @@ from bs4 import BeautifulSoup
 import requests
 import re
 import time
+import datetime as dt
 
 name = 'telegram_util'
 
+def log(*args):
+	text = ' '.join([str(x) for x in args])
+	with open('nohup.out', 'a') as f:
+		f.write('%d:%d %s\n' % (dt.datetime.now().hour, dt.datetime.now().minute, text))
+
 class AlbumResult(object):
 	def __init__(self):
 		self.imgs = []
@@ -50,7 +56,7 @@ def escapeMarkdown(text):
 	text = ''.join(r)
 	for special_char in ['`', '*', 'https://', 'http://']:
 		text = text.replace(special_char, '')
-	text.replace('t.cn/', ' t.cn/')
+	text = text.replace('t.cn/', ' t.cn/')
 	return compactText(text)
 
 def getWid(url):
@@ -181,7 +187,7 @@ class TimedDeleter():
 			self.scheduled = False
 			return
 		self.queue.sort()
-		threading.Timer(self.queue[0] - time.time() + 30, lambda: self.process()).start() 
+		threading.Timer(self.queue[0][0] - time.time() + 30, lambda: self.process()).start() 
 
 	def delete(self, msg, minutes=0):
 		if minutes < 0.1:
